==> physx-jni-0.4.1-sources.jar: physx/physics/PxRaycastQueryResult.java <==
package physx.physics;

import physx.NativeObject;

public class PxRaycastQueryResult extends NativeObject {

    protected PxRaycastQueryResult() { }

    public static PxRaycastQueryResult wrapPointer(long address) {
        return address != 0L ? new PxRaycastQueryResult(address) : null;
    }
    
    protected PxRaycastQueryResult(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: {@link PxRaycastHit} [Value]
     */
    public PxRaycastHit getBlock() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxRaycastHit.wrapPointer(_getBlock(address));
    }
    private static native long _getBlock(long address);

    /**
     * @param value WebIDL type: {@link PxRaycastHit} [Value]
     */
    public void setBlock(PxRaycastHit value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setBlock(address, value.getAddress());
    }
    private static native void _setBlock(long address, long value);

    /**
     * @return WebIDL type: {@link PxRaycastHit}
     */
    public PxRaycastHit getTouches() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxRaycastHit.wrapPointer(_getTouches(address));
    }
    private static native long _getTouches(long address);

    /**
     * @param value WebIDL type: {@link PxRaycastHit}
     */
    public void setTouches(PxRaycastHit value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setTouches(address, value.getAddress());
    }
    private static native void _setTouches(long address, long value);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNbTouches() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getNbTouches(address);
    }
    private static native int _getNbTouches(long address);

    /**
     * @param value WebIDL type: unsigned long
     */
    public void setNbTouches(int value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setNbTouches(address, value);
    }
    private static native void _setNbTouches(long address, int value);

    /**
     * @return WebIDL type: any
     */
    public NativeObject getUserData() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return NativeObject.wrapPointer(_getUserData(address));
    }
    private static native long _getUserData(long address);

    /**
     * @param value WebIDL type: any
     */
    public void setUserData(NativeObject value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setUserData(address, value.getAddress());
    }
    private static native void _setUserData(long address, long value);

    /**
     * @return WebIDL type: octet
     */
    public byte getQueryStatus() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getQueryStatus(address);
    }
    private static native byte _getQueryStatus(long address);

    /**
     * @param value WebIDL type: octet
     */
    public void setQueryStatus(byte value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setQueryStatus(address, value);
    }
    private static native void _setQueryStatus(long address, byte value);

    /**
     * @return WebIDL type: boolean
     */
    public boolean getHasBlock() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getHasBlock(address);
    }
    private static native boolean _getHasBlock(long address);

    /**
     * @param value WebIDL type: boolean
     */
    public void setHasBlock(boolean value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setHasBlock(address, value);
    }
    private static native void _setHasBlock(long address, boolean value);

    // Functions

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNbAnyHits() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getNbAnyHits(address);
    }
    private static native int _getNbAnyHits(long address);

    /**
     * @param index WebIDL type: unsigned long
     * @return WebIDL type: {@link PxRaycastHit} [Const, Ref]
     */
    public PxRaycastHit getAnyHit(int index) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxRaycastHit.wrapPointer(_getAnyHit(address, index));
    }
    private static native long _getAnyHit(long address, int index);

}

==> physx-jni-0.4.16-sources.jar: physx/physics/PxRaycastQueryResult.java <==
package physx.physics;

import physx.NativeObject;

public class PxRaycastQueryResult extends NativeObject {

    protected PxRaycastQueryResult() { }

    public static PxRaycastQueryResult wrapPointer(long address) {
        return address != 0L ? new PxRaycastQueryResult(address) : null;
    }
    
    protected PxRaycastQueryResult(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: {@link PxRaycastHit} [Value]
     */
    public PxRaycastHit getBlock() {
        checkNotNull();
        return PxRaycastHit.wrapPointer(_getBlock(address));
    }
    private static native long _getBlock(long address);

    /**
     * @param value WebIDL type: {@link PxRaycastHit} [Value]
     */
    public void setBlock(PxRaycastHit value) {
        checkNotNull();
        _setBlock(address, value.getAddress());
    }
    private static native void _setBlock(long address, long value);

    /**
     * @return WebIDL type: {@link PxRaycastHit}
     */
    public PxRaycastHit getTouches() {
        checkNotNull();
        return PxRaycastHit.wrapPointer(_getTouches(address));
    }
    private static native long _getTouches(long address);

    /**
     * @param value WebIDL type: {@link PxRaycastHit}
     */
    public void setTouches(PxRaycastHit value) {
        checkNotNull();
        _setTouches(address, value.getAddress());
    }
    private static native void _setTouches(long address, long value);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNbTouches() {
        checkNotNull();
        return _getNbTouches(address);
    }
    private static native int _getNbTouches(long address);

    /**
     * @param value WebIDL type: unsigned long
     */
    public void setNbTouches(int value) {
        checkNotNull();
        _setNbTouches(address, value);
    }
    private static native void _setNbTouches(long address, int value);

    /**
     * @return WebIDL type: any
     */
    public NativeObject getUserData() {
        checkNotNull();
        return NativeObject.wrapPointer(_getUserData(address));
    }
    private static native long _getUserData(long address);

    /**
     * @param value WebIDL type: any
     */
    public void setUserData(NativeObject value) {
        checkNotNull();
        _setUserData(address, value.getAddress());
    }
    private static native void _setUserData(long address, long value);

    /**
     * @return WebIDL type: octet
     */
    public byte getQueryStatus() {
        checkNotNull();
        return _getQueryStatus(address);
    }
    private static native byte _getQueryStatus(long address);

    /**
     * @param value WebIDL type: octet
     */
    public void setQueryStatus(byte value) {
        checkNotNull();
        _setQueryStatus(address, value);
    }
    private static native void _setQueryStatus(long address, byte value);

    /**
     * @return WebIDL type: boolean
     */
    public boolean getHasBlock() {
        checkNotNull();
        return _getHasBlock(address);
    }
    private static native boolean _getHasBlock(long address);

    /**
     * @param value WebIDL type: boolean
     */
    public void setHasBlock(boolean value) {
        checkNotNull();
        _setHasBlock(address, value);
    }
    private static native void _setHasBlock(long address, boolean value);

    // Functions

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNbAnyHits() {
        checkNotNull();
        return _getNbAnyHits(address);
    }
    private static native int _getNbAnyHits(long address);

    /**
     * @param index WebIDL type: unsigned long
     * @return WebIDL type: {@link PxRaycastHit} [Const, Ref]
     */
    public PxRaycastHit getAnyHit(int index) {
        checkNotNull();
        return PxRaycastHit.wrapPointer(_getAnyHit(address, index));
    }
    private static native long _getAnyHit(long address, int index);

}
